==> haskell-th-reify-many-0.1.9-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-reify-many.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-reify-many
version:              0.1.9
visibility:           public
id:                   th-reify-many-0.1.9-3CjG0q2j8wpCHSmqmcDeVI
key:                  th-reify-many-0.1.9-3CjG0q2j8wpCHSmqmcDeVI
license:              BSD-3-Clause
maintainer:           Michael Sloan <mgsloan at gmail>
author:               Michael Sloan
stability:            Experimental
homepage:             http://github.com/mgsloan/th-reify-many
synopsis:             Recurseively reify template haskell datatype info
description:
    @th-reify-many@ provides functions for recursively reifying top
    level declarations.  The main intended use case is for enumerating
    the names of datatypes reachable from an initial datatype, and
    passing these names to some function which generates instances.

category:             Template Haskell
abi:                  53f230067b3353da4e06085fb90300f2
exposed:              True
exposed-modules:
    Language.Haskell.TH.ReifyMany
    Language.Haskell.TH.ReifyMany.Internal

import-dirs:          /usr/lib/ghc-9.0.1/site-local/th-reify-many-0.1.9
library-dirs:         /usr/lib/ghc-9.0.1/site-local/th-reify-many-0.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/th-reify-many-0.1.9
hs-libraries:         HSth-reify-many-0.1.9-3CjG0q2j8wpCHSmqmcDeVI
depends:
    base-4.15.0.0 containers-0.6.4.1 mtl-2.2.2
    safe-0.3.19-BCcHjTM7bV690cTfMWPidj template-haskell-2.17.0.0
    th-expand-syns-0.4.8.0-AG4LIwc5O68DefjPgjG8tP

haddock-interfaces:
    /usr/share/doc/haskell-th-reify-many/html/th-reify-many.haddock

haddock-html:         /usr/share/doc/haskell-th-reify-many/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-reify-many-0.1.9-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-reify-many.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-reify-many
version:              0.1.9
visibility:           public
id:                   th-reify-many-0.1.9-J6smuBgDUcvD3no68woMkJ
key:                  th-reify-many-0.1.9-J6smuBgDUcvD3no68woMkJ
license:              BSD-3-Clause
maintainer:           Michael Sloan <mgsloan at gmail>
author:               Michael Sloan
stability:            Experimental
homepage:             http://github.com/mgsloan/th-reify-many
synopsis:             Recurseively reify template haskell datatype info
description:
    @th-reify-many@ provides functions for recursively reifying top
    level declarations.  The main intended use case is for enumerating
    the names of datatypes reachable from an initial datatype, and
    passing these names to some function which generates instances.

category:             Template Haskell
abi:                  32055f24022881f4fca21955b109fe64
exposed:              True
exposed-modules:
    Language.Haskell.TH.ReifyMany
    Language.Haskell.TH.ReifyMany.Internal

import-dirs:          /usr/lib/ghc-9.0.1/site-local/th-reify-many-0.1.9
library-dirs:         /usr/lib/ghc-9.0.1/site-local/th-reify-many-0.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/th-reify-many-0.1.9
hs-libraries:         HSth-reify-many-0.1.9-J6smuBgDUcvD3no68woMkJ
depends:
    base-4.15.0.0 containers-0.6.4.1 mtl-2.2.2
    safe-0.3.19-BCcHjTM7bV690cTfMWPidj template-haskell-2.17.0.0
    th-expand-syns-0.4.8.0-KX3QpcWOD53DiTfDOXXzhY

haddock-interfaces:
    /usr/share/doc/haskell-th-reify-many/html/th-reify-many.haddock

haddock-html:         /usr/share/doc/haskell-th-reify-many/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
